@@ -1,7 +1,7 @@
 # Excite.pm
 # by Martin Thurn
 # Copyright (C) 1998 by USC/ISI
-# $Id: Excite.pm,v 1.13 1999/07/13 13:47:28 mthurn Exp $
+# $Id: Excite.pm,v 1.14 1999/10/05 19:46:32 mthurn Exp $
 
 =head1 NAME
 
@@ -59,7 +59,9 @@ MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 =head1 VERSION HISTORY
 
-=head2 2.01, 1999-07-13
+=head2 2.02, 1999-10-05
+
+now uses hash_to_cgi_string()
 
 =head2 1.12, 1999-06-29
 
@@ -101,7 +103,7 @@ require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw();
 @ISA = qw(WWW::Search Exporter);
-$VERSION = '2.01';
+$VERSION = '2.02';
 
 use Carp ();
 use WWW::Search(generic_option);
@@ -177,17 +179,8 @@ sub native_setup_search
       } # foreach
     } # if
 
-  # Process the options.
-  my $options = '';
-  foreach (keys %$options_ref) 
-    {
-    # printf STDERR "option: $_ is " . $options_ref->{$_} . "\n";
-    next if (generic_option($_));
-    $options .= $_ . '=' . $options_ref->{$_} . '&';
-    }
-
   # Finally, figure out the url.
-  $self->{_next_url} = $self->{_options}{'search_url'} .'?'. $options;
+  $self->{_next_url} = $self->{_options}{'search_url'} .'?'. $self->hash_to_cgi_string($options_ref);
   } # native_setup_search
 
 
